emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[nongnu] elpa/iedit a089103fa0 110/301: Fix typoes


From: ELPA Syncer
Subject: [nongnu] elpa/iedit a089103fa0 110/301: Fix typoes
Date: Mon, 10 Jan 2022 22:58:55 -0500 (EST)

branch: elpa/iedit
commit a089103fa0cf474f488f160dacac833ce8bdf6e2
Author: Victor Ren <victorhge@gmail.com>
Commit: Victor Ren <victorhge@gmail.com>

    Fix typoes
---
 iedit-lib.el  | 30 +++++++++++++++---------------
 iedit-rect.el |  6 +++---
 2 files changed, 18 insertions(+), 18 deletions(-)

diff --git a/iedit-rect.el b/iedit-rect.el
index 8616785f03..1a874793ab 100644
--- a/iedit-rect.el
+++ b/iedit-rect.el
@@ -2,7 +2,7 @@
 
 ;; Copyright (C) 2010, 2011, 2012 Victor Ren
 
-;; Time-stamp: <2012-08-24 16:26:30 Victor Ren>
+;; Time-stamp: <2012-08-28 15:47:41 Victor Ren>
 ;; Author: Victor Ren <victorhge@gmail.com>
 ;; Keywords: occurrence region simultaneous rectangle refactoring
 ;; Version: 0.97
@@ -28,7 +28,7 @@
 ;;; Commentary:
 
 ;; This package also provides rectangle support with *visible rectangle*
-;; highlighting, which is similar with cua mode rectangle support. But it's
+;; highlighting, which is similar with cua-mode rectangle support. But it is
 ;; lighter weight and uses iedit mechanisms.
 
 ;; The code was developed and fully tested on Gnu Emacs 24.0.93, partially
@@ -85,7 +85,7 @@ current mode is iedit-rect. Otherwise it is nil.
   "Toggle Iedit-rect mode.
 
 When Iedit-rect mode is on, a rectangle is started with visible
-rectangle highlighting.  Rectangle editting support is based on
+rectangle highlighting.  Rectangle editing support is based on
 Iedit mechanism.
 
 Commands:



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/iedit-lib.el b/iedit-lib.el
index 40e2154725..980cd63f22 100644
--- a/iedit-lib.el
+++ b/iedit-lib.el
@@ -1,9 +1,9 @@
-;;; iedit-lib.el --- APIs for editting multiple regions in the same way
+;;; iedit-lib.el --- APIs for editing multiple regions in the same way
 ;;; simultaneously.
 
 ;; Copyright (C) 2010, 2011, 2012 Victor Ren
 
-;; Time-stamp: <2012-08-28 14:59:32 Victor Ren>
+;; Time-stamp: <2012-08-28 15:45:41 Victor Ren>
 ;; Author: Victor Ren <victorhge@gmail.com>
 ;; Keywords: occurrence region simultaneous rectangle refactoring
 ;; Version: 0.97
@@ -108,8 +108,8 @@ insertion against a zero-width occurrence.")
   "Functions to call before iedit-abort. Normally it should be mode exit 
function.")
 
 (defvar iedit-post-undo-hook-installed nil
-  "This is buffer local varialbe which indicated if
-  iedit-post-undo-hook is installed in `post-command-hook'.")
+  "This is buffer local variable which indicated if
+`iedit-post-undo-hook' is installed in `post-command-hook'.")
 
 (defvar iedit-buffering nil
   "This is buffer local variable which indicates iedit-mode is
@@ -256,7 +256,7 @@ occurrences if the user starts typing."
 (defun iedit-post-undo-hook ()
   "Check if it is time to abort iedit.
 
-This is added to `post-command-hook' when undo command is excuted
+This is added to `post-command-hook' when undo command is executed
 in occurrences."
   (if (iedit-same-length)
       nil
@@ -299,7 +299,7 @@ occurrence, it will abort Iedit mode."
           (setq iedit-before-modification-string
                 (buffer-substring-no-properties beg end))
           ;; Check if this is called twice before modification. When inserting
           ;; into zero-width occurrence or between two conjointed occurrecnes,
           ;; both insert-in-front-hooks and insert-behind-hooks will be
           ;; called.  Two calls will make `iedit-skip-modification-once' true.
           (setq iedit-skip-modification-once (not 
iedit-skip-modification-once)))
@@ -336,7 +336,7 @@ occurrence, it will abort Iedit mode."
                                               beginning
                                               ending
                                               change))
-                        (iedit-move-conjointed-overlays another-occurrence)))
+                        (iedit-move-conjoined-overlays another-occurrence)))
                   ;; deletion
                   (dolist (another-occurrence (remove occurrence 
iedit-occurrences-overlays))
                     (let* ((beginning (+ (overlay-start another-occurrence) 
offset))
@@ -535,7 +535,7 @@ This function preserves case."
   (interactive "*")
   (iedit-apply-on-occurrences 'delete-region))
 
-;; todo: add cancel buffering
+;; todo: add cancel buffering function
 (defun iedit-toggle-buffering ()
   "Toggle buffering.
 This is intended to improve iedit's response time.  If the number
@@ -590,7 +590,7 @@ modification is not going to be applied to other 
occurrences."
                 (unless (eq beg end) ;; replacement
                   (goto-char beginning)
                   (insert-and-inherit modified-string))
-                (iedit-move-conjointed-overlays occurrence))))
+                (iedit-move-conjoined-overlays occurrence))))
           (goto-char (+ (overlay-start ov) offset))))))
   (setq iedit-buffering nil)
   ;; (setq iedit-mode (propertize
@@ -601,16 +601,16 @@ modification is not going to be applied to other 
occurrences."
   (message "Buffered modification applied.")
   (setq iedit-before-modification-undo-list nil))
 
-(defun iedit-move-conjointed-overlays (occurrence)
-  "This function keeps overlays conjointed after modification.
-After modification, conjointed overlays may be overlapped."
+(defun iedit-move-conjoined-overlays (occurrence)
+  "This function keeps overlays conjoined after modification.
+After modification, conjoined overlays may be overlapped."
   (let ((beginning (overlay-start occurrence))
         (ending (overlay-end occurrence)))
     (unless (= beginning (point-min))
       (let ((previous-overlay (iedit-find-overlay-at-point
                                (1- beginning)
                                'iedit-occurrence-overlay-name)))
-        (if previous-overlay ; two conjointed occurrences
+        (if previous-overlay ; two conjoined occurrences
             (move-overlay previous-overlay
                           (overlay-start previous-overlay)
                           beginning))))
@@ -618,7 +618,7 @@ After modification, conjointed overlays may be overlapped."
       (let ((next-overlay (iedit-find-overlay-at-point
                            ending
                            'iedit-occurrence-overlay-name)))
-        (if next-overlay ; two conjointed occurrences
+        (if next-overlay ; two conjoined occurrences
             (move-overlay next-overlay ending (overlay-end next-overlay)))))))
 
 (defvar iedit-number-line-counter 1
@@ -654,7 +654,7 @@ FORMAT."
       (dolist (occurrence iedit-occurrences-overlays)
         (goto-char (overlay-start occurrence))
         (insert (format format-string iedit-number-occurrence-counter))
-        (iedit-move-conjointed-overlays occurrence)
+        (iedit-move-conjoined-overlays occurrence)
         (setq iedit-number-occurrence-counter
               (1+ iedit-number-occurrence-counter))))))
 
@@ -299,7 +299,7 @@ occurrence, it will abort Iedit mode."
                 (buffer-substring-no-properties beg end))
           ;; Check if this is called twice before modification. When inserting
-          ;; into zero-width occurrence or between two conjointed occurrecnes,
+          ;; into zero-width occurrence or between two conjoined occurrences,
           ;; both insert-in-front-hooks and insert-behind-hooks will be
           ;; called.  Two calls will make `iedit-skip-modification-once' true.